@@ -44,6 +44,7 @@ __all__ = (
     "ComponentConfigurationTypeDef",
     "ComponentParameterDetailTypeDef",
     "ComponentParameterTypeDef",
+    "ComponentStateTypeDef",
     "ComponentSummaryTypeDef",
     "ComponentTypeDef",
     "ComponentVersionTypeDef",
@@ -121,6 +122,7 @@ __all__ = (
     "InfrastructureConfigurationTypeDef",
     "InstanceBlockDeviceMappingTypeDef",
     "InstanceConfigurationTypeDef",
+    "InstanceMetadataOptionsTypeDef",
     "LaunchPermissionConfigurationTypeDef",
     "LaunchTemplateConfigurationTypeDef",
     "ListComponentBuildVersionsRequestRequestTypeDef",
@@ -279,6 +281,15 @@ ComponentParameterTypeDef = TypedDict(
     },
 )
 
+ComponentStateTypeDef = TypedDict(
+    "ComponentStateTypeDef",
+    {
+        "status": Literal["DEPRECATED"],
+        "reason": str,
+    },
+    total=False,
+)
+
 ComponentSummaryTypeDef = TypedDict(
     "ComponentSummaryTypeDef",
     {
@@ -287,6 +298,7 @@ ComponentSummaryTypeDef = TypedDict(
         "version": str,
         "platform": PlatformType,
         "supportedOsVersions": List[str],
+        "state": "ComponentStateTypeDef",
         "type": ComponentTypeType,
         "owner": str,
         "description": str,
@@ -308,6 +320,7 @@ ComponentTypeDef = TypedDict(
         "type": ComponentTypeType,
         "platform": PlatformType,
         "supportedOsVersions": List[str],
+        "state": "ComponentStateTypeDef",
         "parameters": List["ComponentParameterDetailTypeDef"],
         "owner": str,
         "data": str,
@@ -665,6 +678,7 @@ _OptionalCreateInfrastructureConfigurationRequestRequestTypeDef = TypedDict(
         "terminateInstanceOnFailure": bool,
         "snsTopicArn": str,
         "resourceTags": Mapping[str, str],
+        "instanceMetadataOptions": "InstanceMetadataOptionsTypeDef",
         "tags": Mapping[str, str],
     },
     total=False,
@@ -873,6 +887,7 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
         "snapshotId": str,
         "volumeSize": int,
         "volumeType": EbsVolumeTypeType,
+        "throughput": int,
     },
     total=False,
 )
@@ -1280,6 +1295,7 @@ InfrastructureConfigurationTypeDef = TypedDict(
         "dateCreated": str,
         "dateUpdated": str,
         "resourceTags": Dict[str, str],
+        "instanceMetadataOptions": "InstanceMetadataOptionsTypeDef",
         "tags": Dict[str, str],
     },
     total=False,
@@ -1305,6 +1321,15 @@ InstanceConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+InstanceMetadataOptionsTypeDef = TypedDict(
+    "InstanceMetadataOptionsTypeDef",
+    {
+        "httpTokens": str,
+        "httpPutResponseHopLimit": int,
+    },
+    total=False,
+)
+
 LaunchPermissionConfigurationTypeDef = TypedDict(
     "LaunchPermissionConfigurationTypeDef",
     {
@@ -1891,6 +1916,7 @@ _OptionalUpdateInfrastructureConfigurationRequestRequestTypeDef = TypedDict(
         "terminateInstanceOnFailure": bool,
         "snsTopicArn": str,
         "resourceTags": Mapping[str, str],
+        "instanceMetadataOptions": "InstanceMetadataOptionsTypeDef",
     },
     total=False,
 )
